Re: 1.3.0 creating bigger packs than 1.2.3
- From
Nicolas Pitre <nico@cam.org>
- Date
- Apr 21, 2006, 03:07 UTC
- Message-ID
- <Pine.LNX.4.64.0604202256510.2215@localhost.localdomain>
- In-Reply-To
- <20060421024012.GA1213@spearce.org>
On Thu, 20 Apr 2006, Shawn Pearce wrote:
Show 11 quoted lines
> Nicolas Pitre <nico@cam.org> wrote: > > With the patch above the Linux kernel pack is 0.3% smaller with 1% more > > CPU usage. But like for the diff-delta hash list limiting code this > > small overhead is certainly a good compromize to avoid big degradations > > in some other cases. > > Hmm. See the email I just sent. I was seeing a good 10% increase > in my own tests on a Linux kernel repository. But I guess I can > hope that my test was flawed somehow and it really is closer to a 1% > increase in running time, making it more likely that the above fix > makes it into GIT.
Well, I repeated the kernel run and this time it took 2.5% more CPU with the patch.
But the thing is that I get a +/- 1% difference between successive runs. So while the patch does add a certain overhead, it appears to be in the same range as noise here.
Nicolas